# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: authorization_policies.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61uthorization_policies.proto\x12\x02v1\x1a\roptions.proto\"\xc0\x01\n\x13\x41uthorizationPolicy\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x36\n\x05items\x18\x04 \x03(\x0b\x32\x1b.v1.AuthorizationPolicyItemB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"\xcc\x02\n\x17\x41uthorizationPolicyItem\x12@\n\rprincipal_all\x18\x01 \x01(\x0b\x32\'.v1.AuthorizationPolicyItemPrincipalAllH\x00\x12\x45\n\x10principal_by_ids\x18\x02 \x01(\x0b\x32).v1.AuthorizationPolicyItemPrincipalByIdsH\x00\x12@\n\rresources_all\x18\x03 \x01(\x0b\x32\'.v1.AuthorizationPolicyItemResourcesAllH\x00\x12\x43\n\x0fresource_by_ids\x18\x04 \x01(\x0b\x32(.v1.AuthorizationPolicyItemResourceByIdsH\x00:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_privateB\x06\n\x04item\"@\n#AuthorizationPolicyItemPrincipalAll:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"[\n%AuthorizationPolicyItemPrincipalByIds\x12\x17\n\x03ids\x18\x01 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"@\n#AuthorizationPolicyItemResourcesAll:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"Z\n$AuthorizationPolicyItemResourceByIds\x12\x17\n\x03ids\x18\x01 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_privateBq\n\x19\x63om.strongdm.api.plumbingB\x1d\x41uthorizationPoliciesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_AUTHORIZATIONPOLICY = DESCRIPTOR.message_types_by_name['AuthorizationPolicy']
_AUTHORIZATIONPOLICYITEM = DESCRIPTOR.message_types_by_name['AuthorizationPolicyItem']
_AUTHORIZATIONPOLICYITEMPRINCIPALALL = DESCRIPTOR.message_types_by_name['AuthorizationPolicyItemPrincipalAll']
_AUTHORIZATIONPOLICYITEMPRINCIPALBYIDS = DESCRIPTOR.message_types_by_name['AuthorizationPolicyItemPrincipalByIds']
_AUTHORIZATIONPOLICYITEMRESOURCESALL = DESCRIPTOR.message_types_by_name['AuthorizationPolicyItemResourcesAll']
_AUTHORIZATIONPOLICYITEMRESOURCEBYIDS = DESCRIPTOR.message_types_by_name['AuthorizationPolicyItemResourceByIds']
AuthorizationPolicy = _reflection.GeneratedProtocolMessageType('AuthorizationPolicy', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONPOLICY,
  '__module__' : 'authorization_policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.AuthorizationPolicy)
  })
_sym_db.RegisterMessage(AuthorizationPolicy)

AuthorizationPolicyItem = _reflection.GeneratedProtocolMessageType('AuthorizationPolicyItem', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONPOLICYITEM,
  '__module__' : 'authorization_policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.AuthorizationPolicyItem)
  })
_sym_db.RegisterMessage(AuthorizationPolicyItem)

AuthorizationPolicyItemPrincipalAll = _reflection.GeneratedProtocolMessageType('AuthorizationPolicyItemPrincipalAll', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONPOLICYITEMPRINCIPALALL,
  '__module__' : 'authorization_policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.AuthorizationPolicyItemPrincipalAll)
  })
_sym_db.RegisterMessage(AuthorizationPolicyItemPrincipalAll)

AuthorizationPolicyItemPrincipalByIds = _reflection.GeneratedProtocolMessageType('AuthorizationPolicyItemPrincipalByIds', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONPOLICYITEMPRINCIPALBYIDS,
  '__module__' : 'authorization_policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.AuthorizationPolicyItemPrincipalByIds)
  })
_sym_db.RegisterMessage(AuthorizationPolicyItemPrincipalByIds)

AuthorizationPolicyItemResourcesAll = _reflection.GeneratedProtocolMessageType('AuthorizationPolicyItemResourcesAll', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONPOLICYITEMRESOURCESALL,
  '__module__' : 'authorization_policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.AuthorizationPolicyItemResourcesAll)
  })
_sym_db.RegisterMessage(AuthorizationPolicyItemResourcesAll)

AuthorizationPolicyItemResourceByIds = _reflection.GeneratedProtocolMessageType('AuthorizationPolicyItemResourceByIds', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONPOLICYITEMRESOURCEBYIDS,
  '__module__' : 'authorization_policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.AuthorizationPolicyItemResourceByIds)
  })
_sym_db.RegisterMessage(AuthorizationPolicyItemResourceByIds)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\035AuthorizationPoliciesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _AUTHORIZATIONPOLICY.fields_by_name['id']._options = None
  _AUTHORIZATIONPOLICY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AUTHORIZATIONPOLICY.fields_by_name['name']._options = None
  _AUTHORIZATIONPOLICY.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _AUTHORIZATIONPOLICY.fields_by_name['description']._options = None
  _AUTHORIZATIONPOLICY.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AUTHORIZATIONPOLICY.fields_by_name['items']._options = None
  _AUTHORIZATIONPOLICY.fields_by_name['items']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AUTHORIZATIONPOLICY._options = None
  _AUTHORIZATIONPOLICY._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _AUTHORIZATIONPOLICYITEM._options = None
  _AUTHORIZATIONPOLICYITEM._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _AUTHORIZATIONPOLICYITEMPRINCIPALALL._options = None
  _AUTHORIZATIONPOLICYITEMPRINCIPALALL._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _AUTHORIZATIONPOLICYITEMPRINCIPALBYIDS.fields_by_name['ids']._options = None
  _AUTHORIZATIONPOLICYITEMPRINCIPALBYIDS.fields_by_name['ids']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AUTHORIZATIONPOLICYITEMPRINCIPALBYIDS._options = None
  _AUTHORIZATIONPOLICYITEMPRINCIPALBYIDS._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _AUTHORIZATIONPOLICYITEMRESOURCESALL._options = None
  _AUTHORIZATIONPOLICYITEMRESOURCESALL._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _AUTHORIZATIONPOLICYITEMRESOURCEBYIDS.fields_by_name['ids']._options = None
  _AUTHORIZATIONPOLICYITEMRESOURCEBYIDS.fields_by_name['ids']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AUTHORIZATIONPOLICYITEMRESOURCEBYIDS._options = None
  _AUTHORIZATIONPOLICYITEMRESOURCEBYIDS._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _AUTHORIZATIONPOLICY._serialized_start=52
  _AUTHORIZATIONPOLICY._serialized_end=244
  _AUTHORIZATIONPOLICYITEM._serialized_start=247
  _AUTHORIZATIONPOLICYITEM._serialized_end=579
  _AUTHORIZATIONPOLICYITEMPRINCIPALALL._serialized_start=581
  _AUTHORIZATIONPOLICYITEMPRINCIPALALL._serialized_end=645
  _AUTHORIZATIONPOLICYITEMPRINCIPALBYIDS._serialized_start=647
  _AUTHORIZATIONPOLICYITEMPRINCIPALBYIDS._serialized_end=738
  _AUTHORIZATIONPOLICYITEMRESOURCESALL._serialized_start=740
  _AUTHORIZATIONPOLICYITEMRESOURCESALL._serialized_end=804
  _AUTHORIZATIONPOLICYITEMRESOURCEBYIDS._serialized_start=806
  _AUTHORIZATIONPOLICYITEMRESOURCEBYIDS._serialized_end=896
# @@protoc_insertion_point(module_scope)
