# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: resourcetypes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13resourcetypes.proto\x12\x02v1*\xdf \n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x11RESOURCE_TYPE_AKS\x10\xa5\x06\x12!\n\x1cRESOURCE_TYPE_AKS_BASIC_AUTH\x10\xa6\x06\x12&\n!RESOURCE_TYPE_AKS_SERVICE_ACCOUNT\x10\xa7\x06\x12\x39\n4RESOURCE_TYPE_AKS_SERVICE_ACCOUNT_USER_IMPERSONATION\x10\xaa\x06\x12)\n$RESOURCE_TYPE_AKS_USER_IMPERSONATION\x10\xae\x06\x12 \n\x1bRESOURCE_TYPE_AMAZON_MQAMQP\x10\xc6\x13\x12\x16\n\x11RESOURCE_TYPE_AWS\x10\xfc\x11\x12\x1e\n\x19RESOURCE_TYPE_AWS_CONSOLE\x10\xb8\x17\x12.\n)RESOURCE_TYPE_AWS_CONSOLE_STATIC_KEY_PAIR\x10\xb9\x17\x12\'\n\"RESOURCE_TYPE_AWS_INSTANCE_PROFILE\x10\xfd\x11\x12\x1c\n\x17RESOURCE_TYPE_AEROSPIKE\x10\xf8#\x12\x1d\n\x18RESOURCE_TYPE_AMAZON_EKS\x10\xa2\x06\x12.\n)RESOURCE_TYPE_AMAZON_EKS_INSTANCE_PROFILE\x10\xa9\x06\x12\x41\n<RESOURCE_TYPE_AMAZON_EKS_INSTANCE_PROFILE_USER_IMPERSONATION\x10\xad\x06\x12\x30\n+RESOURCE_TYPE_AMAZON_EKS_USER_IMPERSONATION\x10\xb2\x06\x12\x1c\n\x17RESOURCE_TYPE_AMAZON_ES\x10\xd8\x04\x12\x1f\n\x1aRESOURCE_TYPE_AMAZON_ESIAM\x10\xda\x04\x12$\n\x1fRESOURCE_TYPE_AMAZON_MQAMQP_091\x10\xc5\x13\x12\x18\n\x14RESOURCE_TYPE_ATHENA\x10\x64\x12\x1d\n\x18RESOURCE_TYPE_ATHENA_IAM\x10\xc8\x1a\x12 \n\x1bRESOURCE_TYPE_AURORA_MY_SQL\x10\xcd\x08\x12#\n\x1eRESOURCE_TYPE_AURORA_MY_SQLIAM\x10\xd5\x08\x12\"\n\x1dRESOURCE_TYPE_AURORA_POSTGRES\x10\x95\n\x12&\n!RESOURCE_TYPE_AURORA_POSTGRES_IAM\x10\x9d\n\x12\x18\n\x13RESOURCE_TYPE_AZURE\x10\xf0\x15\x12\x1d\n\x18RESOURCE_TYPE_AZURE_CERT\x10\xf1\x15\x12\x1f\n\x1aRESOURCE_TYPE_AZURE_MY_SQL\x10\xd3\x08\x12\x30\n+RESOURCE_TYPE_AZURE_MY_SQL_MANAGED_IDENTITY\x10\xd6\x08\x12!\n\x1cRESOURCE_TYPE_AZURE_POSTGRES\x10\x9b\n\x12\x32\n-RESOURCE_TYPE_AZURE_POSTGRES_MANAGED_IDENTITY\x10\x9c\n\x12\x1b\n\x16RESOURCE_TYPE_BIGQUERY\x10\xc8\x01\x12\x1c\n\x17RESOURCE_TYPE_CASSANDRA\x10\xac\x02\x12\x18\n\x13RESOURCE_TYPE_CITUS\x10\x99\n\x12\"\n\x1eRESOURCE_TYPE_CLICK_HOUSE_HTTP\x10\x05\x12%\n RESOURCE_TYPE_CLICK_HOUSE_MY_SQL\x10\xd4\x08\x12!\n\x1dRESOURCE_TYPE_CLICK_HOUSE_TCP\x10\x06\x12\x1b\n\x16RESOURCE_TYPE_CLUSTRIX\x10\xce\x08\x12\x1c\n\x17RESOURCE_TYPE_COCKROACH\x10\x97\n\x12%\n RESOURCE_TYPE_COUCHBASE_DATABASE\x10\x81\x19\x12#\n\x1eRESOURCE_TYPE_COUCHBASE_WEB_UI\x10\x80\x19\x12\x19\n\x14RESOURCE_TYPE_DB_2_I\x10\xe0\x12\x12\x1b\n\x16RESOURCE_TYPE_DB_2_LUW\x10\x98\x11\x12#\n\x1eRESOURCE_TYPE_DOCUMENT_DB_HOST\x10\x9c\x08\x12\'\n\"RESOURCE_TYPE_DOCUMENT_DB_HOST_IAM\x10\x9f\x08\x12*\n%RESOURCE_TYPE_DOCUMENT_DB_REPLICA_SET\x10\x9d\x08\x12.\n)RESOURCE_TYPE_DOCUMENT_DB_REPLICA_SET_IAM\x10\xa0\x08\x12\x18\n\x13RESOURCE_TYPE_DRUID\x10\x90\x03\x12\x1c\n\x17RESOURCE_TYPE_DYNAMO_DB\x10\xf4\x03\x12\x1f\n\x1aRESOURCE_TYPE_DYNAMO_DBIAM\x10\xf5\x03\x12\x1a\n\x15RESOURCE_TYPE_ELASTIC\x10\xd9\x04\x12%\n RESOURCE_TYPE_ELASTI_CACHE_REDIS\x10\xc1\x0c\x12)\n$RESOURCE_TYPE_ELASTI_CACHE_REDIS_IAM\x10\xc3\x0c\x12\x1b\n\x16RESOURCE_TYPE_ENTRA_ID\x10\xf3\x15\x12\x16\n\x11RESOURCE_TYPE_GCP\x10\x8c\x15\x12\x1e\n\x19RESOURCE_TYPE_GCP_CONSOLE\x10\xe4\x19\x12\x19\n\x14RESOURCE_TYPE_GCPWIF\x10\x8d\x15\x12\x1a\n\x15RESOURCE_TYPE_GIT_HUB\x10\xe5\x19\x12\x1f\n\x1aRESOURCE_TYPE_GOOGLE_ADMIN\x10\xe6\x19\x12\x1d\n\x18RESOURCE_TYPE_GOOGLE_GKE\x10\xa3\x06\x12\x30\n+RESOURCE_TYPE_GOOGLE_GKE_USER_IMPERSONATION\x10\xb0\x06\x12!\n\x1cRESOURCE_TYPE_GOOGLE_SPANNER\x10\xc0%\x12\x1c\n\x17RESOURCE_TYPE_GREENPLUM\x10\x96\n\x12\x1c\n\x17RESOURCE_TYPE_HTTP_AUTH\x10\xbe\x05\x12\x1d\n\x18RESOURCE_TYPE_HTTP_BASIC\x10\xbc\x05\x12\x1f\n\x1aRESOURCE_TYPE_HTTP_NO_AUTH\x10\xbd\x05\x12\x1d\n\x18RESOURCE_TYPE_KUBERNETES\x10\xa0\x06\x12(\n#RESOURCE_TYPE_KUBERNETES_BASIC_AUTH\x10\xa1\x06\x12*\n%RESOURCE_TYPE_KUBERNETES_POD_IDENTITY\x10\xb3\x06\x12-\n(RESOURCE_TYPE_KUBERNETES_SERVICE_ACCOUNT\x10\xa4\x06\x12@\n;RESOURCE_TYPE_KUBERNETES_SERVICE_ACCOUNT_USER_IMPERSONATION\x10\xa8\x06\x12\x30\n+RESOURCE_TYPE_KUBERNETES_USER_IMPERSONATION\x10\xac\x06\x12\x16\n\x11RESOURCE_TYPE_MCP\x10\xdc$\x12\x19\n\x14RESOURCE_TYPE_MCPDCR\x10\xdd$\x12\x1e\n\x19RESOURCE_TYPE_MTLS_MY_SQL\x10\xd2\x08\x12 \n\x1bRESOURCE_TYPE_MTLS_POSTGRES\x10\x9a\n\x12\x18\n\x13RESOURCE_TYPE_MARIA\x10\xcf\x08\x12\x1c\n\x17RESOURCE_TYPE_MEMCACHED\x10\x84\x07\x12\x1a\n\x15RESOURCE_TYPE_MEM_SQL\x10\xd0\x08\x12 \n\x1bRESOURCE_TYPE_MICROSOFT_365\x10\xe7\x19\x12 \n\x1bRESOURCE_TYPE_MONGO_DB_HOST\x10\xea\x07\x12\x1b\n\x16RESOURCE_TYPE_MONGO_DB\x10\xe8\x07\x12.\n)RESOURCE_TYPE_MONGO_DB_LEGACY_REPLICA_SET\x10\xe9\x07\x12\'\n\"RESOURCE_TYPE_MONGO_DB_REPLICA_SET\x10\xeb\x07\x12+\n&RESOURCE_TYPE_MONGO_DB_SHARDED_CLUSTER\x10\x9e\x08\x12\x19\n\x14RESOURCE_TYPE_MY_SQL\x10\xcc\x08\x12\x1a\n\x15RESOURCE_TYPE_NEPTUNE\x10\xca\x11\x12\x1e\n\x19RESOURCE_TYPE_NEPTUNE_IAM\x10\x99\x11\x12\x1d\n\x18RESOURCE_TYPE_OKTA_ADMIN\x10\xe8\x19\x12\x1e\n\x19RESOURCE_TYPE_OKTA_GROUPS\x10\xac\x1b\x12\x19\n\x14RESOURCE_TYPE_ORACLE\x10\xb0\t\x12\x1d\n\x18RESOURCE_TYPE_ORACLE_NNE\x10\xb1\t\x12\x1b\n\x16RESOURCE_TYPE_POSTGRES\x10\x94\n\x12\x19\n\x14RESOURCE_TYPE_PRESTO\x10\xf8\n\x12\x16\n\x11RESOURCE_TYPE_RDP\x10\xdc\x0b\x12\x1b\n\x16RESOURCE_TYPE_RDP_CERT\x10\xdd\x0b\x12#\n\x1eRESOURCE_TYPE_RDS_POSTGRES_IAM\x10\x9e\n\x12$\n\x1fRESOURCE_TYPE_RABBIT_MQAMQP_091\x10\xc4\x13\x12\x16\n\x11RESOURCE_TYPE_TCP\x10\xa8\x14\x12\x18\n\x13RESOURCE_TYPE_REDIS\x10\xc0\x0c\x12 \n\x1bRESOURCE_TYPE_REDIS_CLUSTER\x10\xc2\x0c\x12\x1b\n\x16RESOURCE_TYPE_REDSHIFT\x10\x98\n\x12\x1f\n\x1aRESOURCE_TYPE_REDSHIFT_IAM\x10\xa0\n\x12*\n%RESOURCE_TYPE_REDSHIFT_SERVERLESS_IAM\x10\x9f\n\x12\x1d\n\x18RESOURCE_TYPE_SQL_SERVER\x10\x88\x0e\x12&\n!RESOURCE_TYPE_SQL_SERVER_AZURE_AD\x10\x8d\x0e\x12&\n!RESOURCE_TYPE_SQL_SERVER_KERBEROS\x10\x92\x0e\x12\x16\n\x11RESOURCE_TYPE_SSH\x10\xec\x0e\x12\x1b\n\x16RESOURCE_TYPE_SSH_CERT\x10\xed\x0e\x12*\n%RESOURCE_TYPE_SSH_CERT_USER_PROVISION\x10\xef\x0e\x12#\n\x1eRESOURCE_TYPE_SSH_CUSTOMER_KEY\x10\xee\x0e\x12\x1f\n\x1aRESOURCE_TYPE_SSH_PASSWORD\x10\xf0\x0e\x12\x1d\n\x18RESOURCE_TYPE_SALESFORCE\x10\xe9\x19\x12\x1f\n\x1aRESOURCE_TYPE_SINGLE_STORE\x10\xd1\x08\x12\x1c\n\x17RESOURCE_TYPE_SNOWFLAKE\x10\xa4\r\x12\x1c\n\x17RESOURCE_TYPE_SNOWSIGHT\x10\xa5\r\x12\x1d\n\x18RESOURCE_TYPE_SYBASE_ASE\x10\xd0\x0f\x12\x1c\n\x17RESOURCE_TYPE_SYBASE_IQ\x10\xd1\x0f\x12\x1b\n\x16RESOURCE_TYPE_TERADATA\x10\xb4\x10\x12\x18\n\x13RESOURCE_TYPE_TRINO\x10\xf9\n\x12\x1a\n\x15RESOURCE_TYPE_VERTICA\x10\x94#Bm\n\x19\x63om.strongdm.api.plumbingB\x14ResourceTypePlumbingZ:github.com/strongdm/web/pkg/api/v1/generated/go_private/v1b\x06proto3')

_RESOURCETYPE = DESCRIPTOR.enum_types_by_name['ResourceType']
ResourceType = enum_type_wrapper.EnumTypeWrapper(_RESOURCETYPE)
RESOURCE_TYPE_UNSPECIFIED = 0
RESOURCE_TYPE_AKS = 805
RESOURCE_TYPE_AKS_BASIC_AUTH = 806
RESOURCE_TYPE_AKS_SERVICE_ACCOUNT = 807
RESOURCE_TYPE_AKS_SERVICE_ACCOUNT_USER_IMPERSONATION = 810
RESOURCE_TYPE_AKS_USER_IMPERSONATION = 814
RESOURCE_TYPE_AMAZON_MQAMQP = 2502
RESOURCE_TYPE_AWS = 2300
RESOURCE_TYPE_AWS_CONSOLE = 3000
RESOURCE_TYPE_AWS_CONSOLE_STATIC_KEY_PAIR = 3001
RESOURCE_TYPE_AWS_INSTANCE_PROFILE = 2301
RESOURCE_TYPE_AEROSPIKE = 4600
RESOURCE_TYPE_AMAZON_EKS = 802
RESOURCE_TYPE_AMAZON_EKS_INSTANCE_PROFILE = 809
RESOURCE_TYPE_AMAZON_EKS_INSTANCE_PROFILE_USER_IMPERSONATION = 813
RESOURCE_TYPE_AMAZON_EKS_USER_IMPERSONATION = 818
RESOURCE_TYPE_AMAZON_ES = 600
RESOURCE_TYPE_AMAZON_ESIAM = 602
RESOURCE_TYPE_AMAZON_MQAMQP_091 = 2501
RESOURCE_TYPE_ATHENA = 100
RESOURCE_TYPE_ATHENA_IAM = 3400
RESOURCE_TYPE_AURORA_MY_SQL = 1101
RESOURCE_TYPE_AURORA_MY_SQLIAM = 1109
RESOURCE_TYPE_AURORA_POSTGRES = 1301
RESOURCE_TYPE_AURORA_POSTGRES_IAM = 1309
RESOURCE_TYPE_AZURE = 2800
RESOURCE_TYPE_AZURE_CERT = 2801
RESOURCE_TYPE_AZURE_MY_SQL = 1107
RESOURCE_TYPE_AZURE_MY_SQL_MANAGED_IDENTITY = 1110
RESOURCE_TYPE_AZURE_POSTGRES = 1307
RESOURCE_TYPE_AZURE_POSTGRES_MANAGED_IDENTITY = 1308
RESOURCE_TYPE_BIGQUERY = 200
RESOURCE_TYPE_CASSANDRA = 300
RESOURCE_TYPE_CITUS = 1305
RESOURCE_TYPE_CLICK_HOUSE_HTTP = 5
RESOURCE_TYPE_CLICK_HOUSE_MY_SQL = 1108
RESOURCE_TYPE_CLICK_HOUSE_TCP = 6
RESOURCE_TYPE_CLUSTRIX = 1102
RESOURCE_TYPE_COCKROACH = 1303
RESOURCE_TYPE_COUCHBASE_DATABASE = 3201
RESOURCE_TYPE_COUCHBASE_WEB_UI = 3200
RESOURCE_TYPE_DB_2_I = 2400
RESOURCE_TYPE_DB_2_LUW = 2200
RESOURCE_TYPE_DOCUMENT_DB_HOST = 1052
RESOURCE_TYPE_DOCUMENT_DB_HOST_IAM = 1055
RESOURCE_TYPE_DOCUMENT_DB_REPLICA_SET = 1053
RESOURCE_TYPE_DOCUMENT_DB_REPLICA_SET_IAM = 1056
RESOURCE_TYPE_DRUID = 400
RESOURCE_TYPE_DYNAMO_DB = 500
RESOURCE_TYPE_DYNAMO_DBIAM = 501
RESOURCE_TYPE_ELASTIC = 601
RESOURCE_TYPE_ELASTI_CACHE_REDIS = 1601
RESOURCE_TYPE_ELASTI_CACHE_REDIS_IAM = 1603
RESOURCE_TYPE_ENTRA_ID = 2803
RESOURCE_TYPE_GCP = 2700
RESOURCE_TYPE_GCP_CONSOLE = 3300
RESOURCE_TYPE_GCPWIF = 2701
RESOURCE_TYPE_GIT_HUB = 3301
RESOURCE_TYPE_GOOGLE_ADMIN = 3302
RESOURCE_TYPE_GOOGLE_GKE = 803
RESOURCE_TYPE_GOOGLE_GKE_USER_IMPERSONATION = 816
RESOURCE_TYPE_GOOGLE_SPANNER = 4800
RESOURCE_TYPE_GREENPLUM = 1302
RESOURCE_TYPE_HTTP_AUTH = 702
RESOURCE_TYPE_HTTP_BASIC = 700
RESOURCE_TYPE_HTTP_NO_AUTH = 701
RESOURCE_TYPE_KUBERNETES = 800
RESOURCE_TYPE_KUBERNETES_BASIC_AUTH = 801
RESOURCE_TYPE_KUBERNETES_POD_IDENTITY = 819
RESOURCE_TYPE_KUBERNETES_SERVICE_ACCOUNT = 804
RESOURCE_TYPE_KUBERNETES_SERVICE_ACCOUNT_USER_IMPERSONATION = 808
RESOURCE_TYPE_KUBERNETES_USER_IMPERSONATION = 812
RESOURCE_TYPE_MCP = 4700
RESOURCE_TYPE_MCPDCR = 4701
RESOURCE_TYPE_MTLS_MY_SQL = 1106
RESOURCE_TYPE_MTLS_POSTGRES = 1306
RESOURCE_TYPE_MARIA = 1103
RESOURCE_TYPE_MEMCACHED = 900
RESOURCE_TYPE_MEM_SQL = 1104
RESOURCE_TYPE_MICROSOFT_365 = 3303
RESOURCE_TYPE_MONGO_DB_HOST = 1002
RESOURCE_TYPE_MONGO_DB = 1000
RESOURCE_TYPE_MONGO_DB_LEGACY_REPLICA_SET = 1001
RESOURCE_TYPE_MONGO_DB_REPLICA_SET = 1003
RESOURCE_TYPE_MONGO_DB_SHARDED_CLUSTER = 1054
RESOURCE_TYPE_MY_SQL = 1100
RESOURCE_TYPE_NEPTUNE = 2250
RESOURCE_TYPE_NEPTUNE_IAM = 2201
RESOURCE_TYPE_OKTA_ADMIN = 3304
RESOURCE_TYPE_OKTA_GROUPS = 3500
RESOURCE_TYPE_ORACLE = 1200
RESOURCE_TYPE_ORACLE_NNE = 1201
RESOURCE_TYPE_POSTGRES = 1300
RESOURCE_TYPE_PRESTO = 1400
RESOURCE_TYPE_RDP = 1500
RESOURCE_TYPE_RDP_CERT = 1501
RESOURCE_TYPE_RDS_POSTGRES_IAM = 1310
RESOURCE_TYPE_RABBIT_MQAMQP_091 = 2500
RESOURCE_TYPE_TCP = 2600
RESOURCE_TYPE_REDIS = 1600
RESOURCE_TYPE_REDIS_CLUSTER = 1602
RESOURCE_TYPE_REDSHIFT = 1304
RESOURCE_TYPE_REDSHIFT_IAM = 1312
RESOURCE_TYPE_REDSHIFT_SERVERLESS_IAM = 1311
RESOURCE_TYPE_SQL_SERVER = 1800
RESOURCE_TYPE_SQL_SERVER_AZURE_AD = 1805
RESOURCE_TYPE_SQL_SERVER_KERBEROS = 1810
RESOURCE_TYPE_SSH = 1900
RESOURCE_TYPE_SSH_CERT = 1901
RESOURCE_TYPE_SSH_CERT_USER_PROVISION = 1903
RESOURCE_TYPE_SSH_CUSTOMER_KEY = 1902
RESOURCE_TYPE_SSH_PASSWORD = 1904
RESOURCE_TYPE_SALESFORCE = 3305
RESOURCE_TYPE_SINGLE_STORE = 1105
RESOURCE_TYPE_SNOWFLAKE = 1700
RESOURCE_TYPE_SNOWSIGHT = 1701
RESOURCE_TYPE_SYBASE_ASE = 2000
RESOURCE_TYPE_SYBASE_IQ = 2001
RESOURCE_TYPE_TERADATA = 2100
RESOURCE_TYPE_TRINO = 1401
RESOURCE_TYPE_VERTICA = 4500


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\024ResourceTypePlumbingZ:github.com/strongdm/web/pkg/api/v1/generated/go_private/v1'
  _RESOURCETYPE._serialized_start=28
  _RESOURCETYPE._serialized_end=4219
# @@protoc_insertion_point(module_scope)
